<?php

/**
 * Controller for Wizard
 *
 **/
class Wizard_Controller extends Authenticated_Controller
{
	/**
	 * Default view
	 *
	 * @param $view string
	 * @return void
	 **/
	function index($view = false)
	{
		if (!wizard_helper::authorized_for_wizard()) {
			return url::redirect('wizard/unauthorized');
		}
		if (!wizard_helper::preconditions()) {
			return url::redirect('wizard/preconditions_failed');
		}
		if(!$view) {
			$view = 'host_wizard';
		}
		csrf::token();
		// Disable keycommands for the wizard
		$this->template->keycommands_disabled = true;
		// This page should never refresh itself
		$this->template->disable_refresh = true;
		// Create a custom header? Is it needed? This prevents the normal menu from rendering
		$this->template->hide_header = true;
		// Prevent dojo from loading
		$this->template->no_dojo = true;
		// Set page content
		$this->template->content = $this->add_view($view);
		// Sets appropriate page title. Depends on naming of the view file, i.e host_wizard.php
		$this->template->title = _(ucwords(str_replace('_', ' ', $view)));
		// Add extra js and css headers
		$this->template->js_header = $this->add_view('js_header');
		$this->template->css_header = $this->add_view('css_header');
		// Reset all css rules
		$this->xtra_css[] = 'application/media/bootstrap/css/bootstrap.css';
		$this->xtra_css[] = 'application/media/bootstrap/css/bootstrap-responsive.css';
		$this->xtra_css[] = 'application/media/bootstrap-aw/css/bootstrap-wizard.css';
		$this->xtra_css[] = 'modules/wizard/media/css/wizard.css';

		$this->xtra_js[] = 'application/media/bootstrap/js/bootstrap.js';
		$this->xtra_js[] = 'application/media/bootstrap-aw/js/bootstrap-wizard.js';
		$this->xtra_js[] = 'modules/wizard/media/js/'.$view.'.js';
		$this->template->css_header->css = $this->xtra_css;
		$this->template->js_header->js = $this->xtra_js;


		// Get setting whether introduction should be skipped and redirection should be made
		$this->template->content->skip_intro = (int)(bool) config::get('wizard.skip-intro', '*');
		$this->template->content->display_at_start = (int)(bool) config::get('wizard.display_at_start', '*');
	}

	/**
	 * Saves a ninja user setting
	 *
	 * @return string
	 **/
	function save_ninja_setting()
	{
		if(!isset($_POST['setting']) ||
			!in_array($_POST['setting'], array('skip-intro', 'display_at_start')) ||
			!isset($_POST['value'])) {
			return json::fail("Missing valid setting");
		}
		if (!Ninja_setting_Model::save_page_setting('wizard.'.$_POST['setting'], '*', (int)(bool) $_POST['value'], Auth::instance()->get_user()->username)) {
			return json::fail("Failed saving user setting");
		}
		json::ok("Setting successfully saved");
	}

	/**
	 * User is not authorized to use the wizard
	 *
	 * @return void
	 **/
	function unauthorized()
	{
		$this->template->content = $this->add_view('unauthorized');
		$this->template->disable_refresh = true;

		$this->template->content->error_message = _('It appears as though you do not have permission to use the wizard');
		$this->template->content->error_description = _('If you believe this is an error, contact your administrator to give you sufficient authorization.');
	}

	/**
	 * Preconditions to use the wizard failed
	 *
	 * @return void
	 **/
	function preconditions_failed()
	{
		$this->template->content = $this->add_view('unauthorized');
		$this->template->disable_refresh = true;

		$this->template->content->error_message = _('Preconditions to use the wizard is not met');
		$this->template->content->error_description = _('Make sure that auth_method ninja is set to true in http_api.yml');
	}

} // END class Wizard_Controller
